import React from "react";

import {
	Table,
	TableBody,
	TableCell,
	TableHead,
	TableHeader,
	TableRow,
} from "@/components/ui/table";

export type ColumnDefinition<T> = {
	header: string;
	key: keyof T | "action";
	render?: (value: T[keyof T], row: T) => React.ReactNode;
	align?: "left" | "right" | "center"; // تحديد المحاذاة
	className?: string;
};

export type CustomDataTableProps<T> = {
	columns: ColumnDefinition<T>[];
	data: T[];
	locale: string;
	classNameTableRow?: string;
};

/**
 * CustomDataTable: A reusable table component
 * @param {Object} props - Props passed to the component
 * @param {Array} props.columns -  props.columns - Array of column definitions ({ header: string, key: string, render?: function, align?: "left" | "right", className?: string })
 * @param {Array} props.data - Array of data objects to display in the table
 * @param {string} props.locale - Locale of the application
 */
export function CustomDataTable<T>({
	columns,
	data,
	locale,
}: CustomDataTableProps<T>) {

	return (
		<Table>
			<TableHeader>
				<TableRow className="border-dashed border-[#DEE2E6]">
					{columns?.map((col, index) => (
						<TableHead
							key={index}
							className={`text-sm text-custom-fifth ${col.align === "center"
								? "text-center"
								: col.align === "right"
									? "text-right"
									: col.align === "left"
										? "text-left"
										: locale === "ar"
											? "text-right"
											: "text-left"
								}`}
						>
							{col.header}
						</TableHead>
					))}
				</TableRow>
			</TableHeader>
			<TableBody>
				{data?.map((row, rowIndex) => (
					<TableRow key={rowIndex} className="border-dashed border-[#DEE2E6]">
						{columns?.map((col, colIndex) => (
							<TableCell
								key={colIndex}
								className={`text-sm ${col.align === "center"
									? "text-center"
									: col.align === "right"
										? "text-right"
										: col.align === "left"
											? "text-left"
											: locale === "ar"
												? "text-right"
												: "text-left"
									} ${col.className || ""}`}
							>
								{col.render ? (
									col.render(row[col.key as keyof T], row)
								) : (
									<>{String(row[col.key as keyof T])}</>
								)}
							</TableCell>
						))}
					</TableRow>
				))}
			</TableBody>
		</Table>
	);
}
